(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14534,        476]*)
(*NotebookOutlinePosition[     15395,        506]*)
(*  CellTagsIndexPosition[     15351,        502]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Pr\[AAcute]ctica 3", "Subtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
 En esta pr\[AAcute]ctica se pretende dar a conocer algunas capacidades gr\
\[AAcute]ficas de Mathematica, para dibujar figuras geom\[EAcute]tricas \
simples, as\[IAcute] como para representar de funciones de una y dos \
variables, dadas en forma expl\[IAcute]cita y param\[EAcute]trica; con \
numerosas opciones y posibilidades.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell["Figuras geom\[EAcute]tricas y gr\[AAcute]ficos primitivos", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell["\<\
 Las gr\[AAcute]ficas de de ciertas curvas y  figuras geom\[EAcute]tricas \
conocidas se pueden obtener f\[AAcute]cilmente. Concretamente las de una \
recta o de una poligonal, un ret\[AAcute]ngulo, un c\[IAcute]rculo, un disco, \
un pol\[IAcute]gono,  un paralelep\[IAcute]pedo, etc. Primero se obtienen y \
despu\[EAcute]s se muestran con la sentencia Show. Veamos unos ejemplos\
\>", "Text",
  CellHorizontalScrolling->False],

Cell["Clear[\"Global`*\"]", "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["linea1=Graphics[Line[{{1,1},{2,3}}]];", "Input",
  PageWidth->Infinity],

Cell["\<\
linea2=Graphics[Line[{{1,1},{2,3},{3,8},
\t\t\t{4,4},{5,-10}}]];\
\>", "Input",
  PageWidth->Infinity],

Cell["circunferencia=Graphics[Circle[{1,1},5]];", "Input",
  PageWidth->Infinity],

Cell["disco=Graphics[Disk[{1,1},5]];", "Input",
  PageWidth->Infinity],

Cell["rectangulo=Graphics[Rectangle[{1,1},{3,8}]];", "Input",
  PageWidth->Infinity],

Cell["poligono1=Graphics[Polygon[{{1,1},{2,3},{3,8}}]];", "Input",
  PageWidth->Infinity],

Cell["\<\
poligono2=Graphics[Polygon[{{1,1},{2,3},
\t\t\t  {3,8},{4,4}}]];\
\>", "Input",
  PageWidth->Infinity],

Cell["paralelepipedo=Graphics3D[Cuboid[{0,0,0},{2,3,3}]];", "Input",
  PageWidth->Infinity],

Cell["Show[linea1];", "Input",
  PageWidth->Infinity],

Cell["Show[linea2];", "Input",
  PageWidth->Infinity],

Cell["Show[linea1,linea2];", "Input",
  PageWidth->Infinity],

Cell["Show[circunferencia];", "Input",
  PageWidth->Infinity],

Cell["\<\
Parece una elipse en lugar de una circunferencia. Esto es debido a que las \
escalas en las direcciones horizontal y vertical son diferentes. Si se quiere \
otra escala hay que indicarlo con la sentencia AspectRatio, \
asign\[AAcute]ndole en este caso el valor 1 o Automatic.\
\>", "Text",
  CellHorizontalScrolling->False],

Cell["Show[circunferencia,AspectRatio->1];", "Input",
  PageWidth->Infinity],

Cell["Show[disco, AspectRatio->Automatic];", "Input",
  PageWidth->Infinity],

Cell["Show[rectangulo];", "Input",
  PageWidth->Infinity],

Cell["Show[poligono1];", "Input",
  PageWidth->Infinity],

Cell["Show[poligono2];", "Input",
  PageWidth->Infinity],

Cell["Show[paralelepipedo];", "Input",
  PageWidth->Infinity],

Cell[" Dibujo de curvas y superficies", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell["\<\
Las sentencias Plot, Plot3D, ParametricPlot y ParametricPlot3D, seguidas de \
la funci\[OAcute]n o funciones correspondientes y de los l\[IAcute]mites de \
variaci\[OAcute]n de las variables (entre llaves), todo entre corchetes, \
sirven para dibujar curvas y superficies. Las superficies son las que llevan \
3D en la sentencia. Las sentencias que empiezan por Parametric son para las \
curvas o las superficies que est\[AAcute]n dadas en param\[EAcute]tricas, las \
dem\[AAcute]s son para las funciones en expl\[IAcute]citas. A lo largo de la \
pr\[AAcute]ctica vemos ejemplos de curvas y superficies tanto en forma expl\
\[IAcute]cita como en  param\[EAcute]trica. \
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["Plot[Sin[x],{x,0,2 Pi}];", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["Plot[(x^2-4)/((x+1) (x-1) (x-3)),{x,-4,10}];", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["Plot3D[x^2+y^2,{x,-5,5},{y,-5,5}];", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Si deseamos ver la superficie desde otro punto de vista debemos usar la \
sentencia ViewPoint e indicar el punto donde nos situamos (mirando hacia el \
origen)\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
 Plot3D[x^2+y^2,{x,-5,5},{y,-5,5},
\tViewPoint->{7,3,0}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Si deseamos m\[AAcute]s resoluci\[OAcute]n debemos usar la sentencia \
PlotPoints e indicar el n\[UAcute]mero de puntos de resoluci\[OAcute]n (suele \
ponerse entre 20 y 50,  porque si se pone un n\[UAcute]mero mucho mayor tarda \
bastante tiempo en hacer la representaci\[OAcute]n)\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
Plot3D[x^2+y^2,{x,-5,5},{y,-5,5},PlotPoints->25,
\t\t\tViewPoint->{7,3,0}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Plot3D[x^2-y^2,{x,-5,5},{y,-5,5},PlotPoints->20,
\t\t\tViewPoint->{7,3,0}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["Plot3D[x^2-y^2,{x,-5,5},{y,-5,5}];", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Otra sentencia interesante es la que permite obtener curvas de nivel, sobre \
el plano XY, de una determinada superficie. Para ello debemos escribir \
ContourPlot\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["ContourPlot[x^2-y^2,{x,-5,5},{y,-5,5}];", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[" Veamos algunas superficies m\[AAcute]s", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
Plot3D[(x^2+3 y^2) E^(1-x^2-y^2),
\t{x,-2,2},{y,-2,2}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Plot3D[(x^2+3 y^2) E^(1-x^2-y^2),
\t{x,-2,2},{y,-2,2},
\tPlotPoints->25,ViewPoint->{2,-2,0}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
ContourPlot[(x^2+3 y^2) E^(1-x^2-y^2),
\t{x,-2,2},{y,-2,2},PlotPoints->25];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
  Se pueden representar de forma simult\[AAcute]nea varias curvas, en tal \
caso se separan unas de otras con llaves como se hizo con los elementos de \
las matrices. Adem\[AAcute]s es posible dibujarlas con colores diferentes, \
para ello usamos PlotStyle y RGBColor, con intensidades comprendidas entre \
cero y uno. Podemos usar los colores puros (uno de ellos vale 1 y los dem\
\[AAcute]s cero: rojo, verde y azul) o mezclas en diferentes proporciones. \
Por ejemplo la circunferencia, en param\[EAcute]tricas, puede dibujarse \
usando las funciones seno y coseno. Dibujaremos tres circunferencias conc\
\[EAcute]ntricas de radios 1,2 y 3, y diferentes colores\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
ParametricPlot[{{3 Sin[t], 3 Cos[t]},
{2 Sin[t], 2 Cos[t]},{Sin[t], Cos[t]}},{t,0,2 Pi},
PlotStyle->{RGBColor[1,0,0],RGBColor[0,1,0],
RGBColor[0,0,1]},AspectRatio->1];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[" En forma  expl\[IAcute]cita se opera de la siguiente manera:", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
Plot[{Sin[x],Cos[x]}, {x,0,2Pi}, PlotStyle->
{RGBColor[1,0,0],RGBColor[0,0,1]}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Usaremos la sentencia de estilo Thickness para darle mayor grosor a la \
curva\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
Plot[Sin[x],{x,-7,7}, PlotStyle->Thickness[0.02],
                 AspectRatio->0.1];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[" La orden ListPlot", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell["\<\
Para representar  gr\[AAcute]ficamente  una lista de puntos. Si las abscisas \
son los n\[UAcute]meros 1,2,3,.. como en el primer caso no es necesario \
especificarlos. Si las abscisas no son los n\[UAcute]meros 1,2,3... hay que \
escribir las coordenadas de cada punto entre llaves y separados por comas, \
como en el segundo caso.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
ListPlot[{1,2,4,16,38},
\tPlotStyle->{PointSize[0.02]}]; \
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
ListPlot[{{1.5,1},{2,2},{2.5,4},{4,16},{4.5,38}},
\tPlotStyle->{PointSize[0.02]}];\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell["\<\
Ahora ya puede continuar dibujando otras curvas y superficies.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[" Ejercicios", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
 1.- Dibuje la poligonal correspondiente a las abscisas 1,2,3,4,5 y a las \
ordenadas correspondientes a sus datos d1, d2, d3 ,d4, dm.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667],
  FontVariations->{"Outline"->False,
  "Shadow"->False}],

Cell["\<\
 2.- Dibuje la curva (d1+d2) x^3+(d3+d4)x^2- ds x,  en el intervalo [dm-3, \
dm+3]\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
 3.- Escriba la orden para calcular y mostrar simult\[AAcute]neamente un rect\
\[AAcute]ngulo inscrito en un c\[IAcute]rculo de centro el origen y radio 10.\
\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
 4.- Dibuje:
\tun arco de circunferencia de radio 3, centrado en el punto (1/ds,1/dm); que \
recorra los \[AAcute]ngulos  Pi/ds  a  Pi/2;
\t
\tuna elipse centrada en (0,0) y de semiejes  1+1/dm  y  2+d1/dm  e inserte, \
en el interior,  el texto  \"elipse\".\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\

5.- Cree y represente conjuntamente las par\[AAcute]bolas:
\t\t(-1)^i   (x-d1/dm)^2 + 1/dm ;   i=1,2,3,4.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667]],

Cell["\<\

6.- Cree y represente conjuntamente las par\[AAcute]bolas del ejercicio \
anterior, pero con distintos colores, y cambiando el grosor de alguna de \
ellas, o presentandola segmentada.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667]],

Cell["\<\

7.- Obtenga visualmente, mediante las sentencias gr\[AAcute]ficas de \
Mathematica, una aproximaci\[OAcute]n de la  posici\[OAcute]n y valor de un m\
\[AAcute]ximo de la superficie

\t(x^2+y^4+d1)/E^(x^2+y^2) + d1 x/20 -d1 y/15

que est\[EAcute] cercano al origen. Utilice para ello, tanto la \
gr\[AAcute]fica tridimensional de la funci\[OAcute]n de dos variables, como \
las correspondientes curvas de nivel y gr\[AAcute]fico de densidades de la \
misma. Utilice convenientemente las opciones  PlotPoints  y  PlotRange para \
controlar la resoluci\[OAcute]n y el rango de las mismas.  Parta inicialmente \
del cuadrado  [-1,1]x[-1,1]  y dismin\[UAcute]yalo convenientemente para \
mejorar la aproximaci\[OAcute]n visual.\
\>", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  FontFamily->"Times New Roman",
  FontColor->RGBColor[0, 0, 0.500008],
  Background->GrayLevel[0.666667]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 542}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{665, 464},
WindowMargins->{{1, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 145, 4, 54, "Subtitle"],
Cell[1857, 55, 409, 8, 71, "Text"],
Cell[2269, 65, 135, 2, 47, "Subsection"],
Cell[2407, 69, 438, 7, 71, "Text"],
Cell[2848, 78, 181, 6, 46, "Input"],
Cell[3032, 86, 77, 1, 30, "Input"],
Cell[3112, 89, 112, 4, 48, "Input"],
Cell[3227, 95, 81, 1, 30, "Input"],
Cell[3311, 98, 70, 1, 30, "Input"],
Cell[3384, 101, 84, 1, 30, "Input"],
Cell[3471, 104, 89, 1, 30, "Input"],
Cell[3563, 107, 112, 4, 48, "Input"],
Cell[3678, 113, 91, 1, 30, "Input"],
Cell[3772, 116, 53, 1, 30, "Input"],
Cell[3828, 119, 53, 1, 30, "Input"],
Cell[3884, 122, 60, 1, 30, "Input"],
Cell[3947, 125, 61, 1, 30, "Input"],
Cell[4011, 128, 333, 6, 52, "Text"],
Cell[4347, 136, 76, 1, 30, "Input"],
Cell[4426, 139, 76, 1, 30, "Input"],
Cell[4505, 142, 57, 1, 30, "Input"],
Cell[4565, 145, 56, 1, 30, "Input"],
Cell[4624, 148, 56, 1, 30, "Input"],
Cell[4683, 151, 61, 1, 30, "Input"],
Cell[4747, 154, 109, 2, 47, "Subsection"],
Cell[4859, 158, 774, 13, 109, "Text"],
Cell[5636, 173, 90, 2, 30, "Input"],
Cell[5729, 177, 110, 2, 30, "Input"],
Cell[5842, 181, 100, 2, 30, "Input"],
Cell[5945, 185, 265, 7, 52, "Text"],
Cell[6213, 194, 131, 5, 48, "Input"],
Cell[6347, 201, 388, 8, 52, "Text"],
Cell[6738, 211, 149, 5, 48, "Input"],
Cell[6890, 218, 149, 5, 48, "Input"],
Cell[7042, 225, 100, 2, 30, "Input"],
Cell[7145, 229, 268, 7, 52, "Text"],
Cell[7416, 238, 105, 2, 30, "Input"],
Cell[7524, 242, 137, 3, 33, "Text"],
Cell[7664, 247, 129, 5, 48, "Input"],
Cell[7796, 254, 167, 6, 66, "Input"],
Cell[7966, 262, 149, 5, 48, "Input"],
Cell[8118, 269, 770, 13, 109, "Text"],
Cell[8891, 284, 241, 7, 84, "Input"],
Cell[9135, 293, 159, 3, 33, "Text"],
Cell[9297, 298, 154, 5, 48, "Input"],
Cell[9454, 305, 184, 6, 33, "Text"],
Cell[9641, 313, 159, 5, 48, "Input"],
Cell[9803, 320, 96, 2, 47, "Subsection"],
Cell[9902, 324, 438, 9, 71, "Text"],
Cell[10343, 335, 131, 5, 48, "Input"],
Cell[10477, 342, 156, 5, 48, "Input"],
Cell[10636, 349, 168, 5, 33, "Text"],
Cell[10807, 356, 115, 3, 47, "Subsection"],
Cell[10925, 361, 429, 12, 49, "Text"],
Cell[11357, 375, 444, 15, 49, "Text"],
Cell[11804, 392, 520, 16, 49, "Text"],
Cell[12327, 410, 620, 19, 106, "Text"],
Cell[12950, 431, 293, 9, 87, "Text"],
Cell[13246, 442, 371, 10, 87, "Text"],
Cell[13620, 454, 910, 20, 220, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

